@@ -210,7 +210,8 @@ class Link(object):
 
     def _isVFhidden(self):
         if self.address == '00:00:00:00:00:00':
-            return True
+            if self._is_vmfex():
+                return True
         # We hide a VF if there exists a macvtap device with the same address.
         # We assume that such VFs are used by a VM and should not be reported
         # as host nics
@@ -221,6 +222,9 @@ class Link(object):
                 return True
         return False
 
+    def _is_vmfex(self):
+        return drv_name(self.name) == 'enic'
+
     @property
     def oper_up(self):
         return bool(link.get_link(self.name)['flags'] & link.IFF_RUNNING)
